@@ -1,4 +1,4 @@
-// Copyright 2020 Daniel Parker
+// Copyright 2013-2024 Daniel Parker
 // Distributed under the Boost license, Version 1.0.
 // (See accompanying file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
 
@@ -7,7 +7,7 @@
 #ifndef JSONCONS_JSONSCHEMA_JSONSCHEMA_HPP
 #define JSONCONS_JSONSCHEMA_JSONSCHEMA_HPP
 
-#include <jsoncons_ext/jsonschema/keyword_validator.hpp>
+#include <jsoncons_ext/jsonschema/json_schema_factory.hpp>
 #include <jsoncons_ext/jsonschema/json_validator.hpp>
 
 #endif // JSONCONS_JSONSCHEMA_JSONSCHEMA_HPP
